@@ -1,4 +1,4 @@
-use super::{user::UserCompact, GameMode};
+use super::{user::UserCompact, Cursor, GameMode};
 use crate::{request::GetUser, Osu, OsuResult};
 
 use chrono::{DateTime, Utc};
@@ -260,6 +260,29 @@ pub struct BeatmapsetCommentNominate {
     pub modes: Vec<GameMode>,
 }
 
+#[derive(Clone, Debug, Deserialize, Eq, PartialEq, Serialize)]
+pub struct BeatmapsetCommentOwnerChange {
+    #[serde(
+        default,
+        rename = "beatmap_discussion_id",
+        skip_serializing_if = "Option::is_none"
+    )]
+    pub map_discussion_id: Option<u64>,
+    #[serde(
+        default,
+        rename = "beatmap_discussion_post_id",
+        skip_serializing_if = "Option::is_none"
+    )]
+    pub map_discussion_post_id: Option<u64>,
+    #[serde(rename = "beatmap_id")]
+    pub map_id: u32,
+    #[serde(rename = "beatmap_version")]
+    pub version: String,
+    pub new_user_id: u32,
+    #[serde(rename = "new_user_username")]
+    pub new_username: String,
+}
+
 #[derive(Clone, Debug, Deserialize, Eq, PartialEq, Serialize)]
 pub struct BeatmapsetCompact {
     pub artist: String,
@@ -394,6 +417,7 @@ impl Eq for BeatmapsetDiscussion {}
 
 #[derive(Clone, Debug, Deserialize, Eq, PartialEq, Serialize)]
 #[serde(rename_all = "snake_case", tag = "type")]
+#[non_exhaustive]
 pub enum BeatmapsetEvent {
     Disqualify {
         #[serde(rename = "id")]
@@ -498,6 +522,16 @@ pub enum BeatmapsetEvent {
         #[serde(rename = "beatmapset")]
         mapset: BeatmapsetCompact,
     },
+    #[serde(rename = "beatmap_owner_change")]
+    OwnerChange {
+        #[serde(rename = "id")]
+        event_id: u64,
+        comment: BeatmapsetCommentOwnerChange,
+        created_at: DateTime<Utc>,
+        user_id: u32,
+        #[serde(rename = "beatmapset")]
+        mapset: BeatmapsetCompact,
+    },
     Rank {
         #[serde(rename = "id")]
         event_id: u64,
@@ -559,20 +593,6 @@ pub struct BeatmapsetReviewsConfig {
     pub max_blocks: u32,
 }
 
-#[derive(Clone, Debug, Deserialize, PartialEq, Serialize)]
-pub(crate) struct BeatmapsetSearchCursor {
-    #[serde(rename = "_id")]
-    pub(crate) id: String,
-    #[serde(
-        default,
-        rename = "play_count",
-        skip_serializing_if = "Option::is_none"
-    )]
-    pub(crate) playcount: Option<String>,
-    #[serde(default, rename = "_score", skip_serializing_if = "Option::is_none")]
-    pub(crate) score: Option<f32>,
-}
-
 #[derive(Copy, Clone, Debug, Eq, PartialEq)]
 pub(crate) enum SearchRankStatus {
     Any,
@@ -792,7 +812,7 @@ impl<'de> Deserialize<'de> for BeatmapsetSearchParameters {
 
 #[derive(Clone, Debug, PartialEq, Serialize)]
 pub struct BeatmapsetSearchResult {
-    cursor: Option<BeatmapsetSearchCursor>,
+    cursor: Option<Cursor>,
     #[serde(rename(serialize = "beatmapsets"))]
     pub mapsets: Vec<Beatmapset>,
     #[serde(rename(serialize = "search"))]
@@ -1098,6 +1118,12 @@ def_enum!(u8 Genre {
     Jazz = 14 ("Jazz"),
 });
 
+impl Default for Genre {
+    fn default() -> Self {
+        Self::Any
+    }
+}
+
 def_enum!(u8 Language {
     Any = 0,
     Other = 1,
@@ -1116,6 +1142,12 @@ def_enum!(u8 Language {
     Unspecified = 14,
 });
 
+impl Default for Language {
+    fn default() -> Self {
+        Self::Any
+    }
+}
+
 struct DescriptionVisitor;
 
 impl<'de> Visitor<'de> for DescriptionVisitor {
@@ -1180,11 +1212,7 @@ mod tests {
     #[test]
     fn ser_de_search_result_any_status() {
         let search_result = BeatmapsetSearchResult {
-            cursor: Some(BeatmapsetSearchCursor {
-                id: "123".to_owned(),
-                score: Some(3.1415),
-                playcount: None,
-            }),
+            cursor: None,
             mapsets: Vec::new(),
             params: BeatmapsetSearchParameters {
                 query: Some("my query".to_owned()),
@@ -1207,11 +1235,7 @@ mod tests {
     #[test]
     fn ser_de_search_result_specific_status() {
         let search_result = BeatmapsetSearchResult {
-            cursor: Some(BeatmapsetSearchCursor {
-                id: "123".to_owned(),
-                score: None,
-                playcount: Some("123".to_owned()),
-            }),
+            cursor: None,
             mapsets: Vec::new(),
             params: BeatmapsetSearchParameters {
                 query: None,
