@@ -1,6 +1,6 @@
 use super::{
-    beatmap::BeatmapCompact, deflate_acc, score::ScoreStatistics, user::UserCompact, GameMode,
-    GameMods,
+    beatmap::BeatmapCompact, deflate_acc, score::ScoreStatistics, user::UserCompact, Cursor,
+    GameMode, GameMods,
 };
 use crate::{Osu, OsuResult};
 
@@ -417,7 +417,7 @@ impl Eq for MatchInfo {}
 #[derive(Clone, Debug, Deserialize, Eq, PartialEq, Serialize)]
 pub struct MatchList {
     #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub(crate) cursor: Option<MatchListCursor>,
+    pub(crate) cursor: Option<Cursor>,
     pub matches: Vec<MatchInfo>,
     pub params: MatchListParams,
 }
@@ -432,15 +432,10 @@ impl MatchList {
     /// Otherwise, this method returns `None`.
     #[inline]
     pub async fn get_next(&self, osu: &Osu) -> Option<OsuResult<MatchList>> {
-        Some(osu.osu_matches().cursor(self.cursor?).await)
+        Some(osu.osu_matches().cursor(self.cursor.clone()?).await)
     }
 }
 
-#[derive(Copy, Clone, Debug, Deserialize, Eq, PartialEq, Serialize)]
-pub(crate) struct MatchListCursor {
-    pub(crate) match_id: u32,
-}
-
 #[derive(Clone, Debug, Deserialize, Eq, PartialEq, Serialize)]
 pub struct MatchListParams {
     pub limit: u32,
@@ -915,12 +910,24 @@ def_enum!(u8 ScoringType {
     ScoreV2 = 3 ("scorev2"),
 });
 
+impl Default for ScoringType {
+    fn default() -> Self {
+        Self::Score
+    }
+}
+
 def_enum!(u8 Team {
     None = 0 ("none"),
     Blue = 1 ("blue"),
     Red = 2 ("red"),
 });
 
+impl Default for Team {
+    fn default() -> Self {
+        Self::None
+    }
+}
+
 def_enum!(u8 TeamType {
     HeadToHead = 0 ("head-to-head"),
     TagCoop = 1 ("tag-coop"),
@@ -928,6 +935,12 @@ def_enum!(u8 TeamType {
     TagTeamVS = 3 ("tag-team-vs"),
 });
 
+impl Default for TeamType {
+    fn default() -> Self {
+        Self::HeadToHead
+    }
+}
+
 struct Bool(bool);
 struct BoolVisitor;
 
