@@ -109,12 +109,14 @@ impl<'a> GetUser<'a> {
             UserId::Name(_) => "username",
         };
 
-        query.push("key", kind);
+        query.push("key", &kind);
 
-        let req = Request::from(Route::GetUser {
+        let route = Route::GetUser {
             user_id,
             mode: self.mode,
-        });
+        };
+
+        let req = Request::with_query(route, query);
 
         Box::pin(self.osu.inner.request(req))
     }
@@ -168,7 +170,7 @@ impl<'a> GetUserBeatmapsets<'a> {
             fut: None,
             osu,
             user_id: Some(user_id),
-            map_type: "ranked_and_approved",
+            map_type: "ranked",
             limit: None,
             offset: None,
         }
@@ -190,15 +192,16 @@ impl<'a> GetUserBeatmapsets<'a> {
 
     pub fn map_type(mut self, map_type: RankStatus) -> Self {
         self.map_type = match map_type {
-            RankStatus::Approved | RankStatus::Ranked => "ranked_and_approved",
+            RankStatus::Approved | RankStatus::Ranked => "ranked",
             RankStatus::Graveyard => "graveyard",
-            RankStatus::Pending | RankStatus::WIP | RankStatus::Qualified => "unranked",
+            RankStatus::Pending | RankStatus::WIP | RankStatus::Qualified => "pending",
             RankStatus::Loved => "loved",
         };
 
         self
     }
 
+    /// Require mapset rank status to be `loved`
     #[inline]
     pub fn loved(mut self) -> Self {
         self.map_type = "loved";
@@ -206,13 +209,7 @@ impl<'a> GetUserBeatmapsets<'a> {
         self
     }
 
-    #[inline]
-    pub fn favourite(mut self) -> Self {
-        self.map_type = "favourite";
-
-        self
-    }
-
+    /// Require mapset rank status to be `graveyard`
     #[inline]
     pub fn graveyard(mut self) -> Self {
         self.map_type = "graveyard";
@@ -220,16 +217,18 @@ impl<'a> GetUserBeatmapsets<'a> {
         self
     }
 
+    /// Require mapset rank status to be either `ranked` or `approved`
     #[inline]
-    pub fn ranked_and_approved(mut self) -> Self {
-        self.map_type = "ranked_and_approved";
+    pub fn ranked(mut self) -> Self {
+        self.map_type = "ranked";
 
         self
     }
 
+    /// Require mapset rank status to be `pending`
     #[inline]
-    pub fn unranked(mut self) -> Self {
-        self.map_type = "unranked";
+    pub fn pending(mut self) -> Self {
+        self.map_type = "pending";
 
         self
     }
@@ -242,17 +241,17 @@ impl<'a> GetUserBeatmapsets<'a> {
         let mut query = Query::new();
 
         if let Some(limit) = self.limit {
-            query.push("limit", limit.to_string());
+            query.push("limit", &limit);
         }
 
         if let Some(offset) = self.offset {
-            query.push("offset", offset.to_string());
+            query.push("offset", &offset);
         }
 
         #[cfg(not(feature = "cache"))]
         {
             let user_id = self.user_id;
-            let req = Request::from((query, Route::GetUserBeatmapsets { user_id, map_type }));
+            let req = Request::with_query(Route::GetUserBeatmapsets { user_id, map_type }, query);
 
             Box::pin(self.osu.inner.request(req))
         }
@@ -265,7 +264,7 @@ impl<'a> GetUserBeatmapsets<'a> {
                 .osu
                 .cache_user(self.user_id.take().unwrap())
                 .map_ok(move |user_id| {
-                    Request::from((query, Route::GetUserBeatmapsets { user_id, map_type }))
+                    Request::with_query(Route::GetUserBeatmapsets { user_id, map_type }, query)
                 })
                 .and_then(move |req| osu.request(req));
 
@@ -338,17 +337,17 @@ impl<'a> GetUserKudosu<'a> {
         let mut query = Query::new();
 
         if let Some(limit) = self.limit {
-            query.push("limit", limit.to_string());
+            query.push("limit", &limit);
         }
 
         if let Some(offset) = self.offset {
-            query.push("offset", offset.to_string());
+            query.push("offset", &offset);
         }
 
         #[cfg(not(feature = "cache"))]
         {
             let user_id = self.user_id;
-            let req = Request::from((query, Route::GetUserKudosu { user_id }));
+            let req = Request::with_query(Route::GetUserKudosu { user_id }, query);
 
             Box::pin(self.osu.inner.request(req))
         }
@@ -360,7 +359,7 @@ impl<'a> GetUserKudosu<'a> {
             let fut = self
                 .osu
                 .cache_user(self.user_id.take().unwrap())
-                .map_ok(move |user_id| Request::from((query, Route::GetUserKudosu { user_id })))
+                .map_ok(move |user_id| Request::with_query(Route::GetUserKudosu { user_id }, query))
                 .and_then(move |req| osu.request(req));
 
             Box::pin(fut)
@@ -433,22 +432,21 @@ impl<'a> GetUserMostPlayed<'a> {
         let mut query = Query::new();
 
         if let Some(limit) = self.limit {
-            query.push("limit", limit.to_string());
+            query.push("limit", &limit);
         }
 
         if let Some(offset) = self.offset {
-            query.push("offset", offset.to_string());
+            query.push("offset", &offset);
         }
 
         #[cfg(not(feature = "cache"))]
         {
-            let req = Request::from((
-                query,
-                Route::GetUserBeatmapsets {
-                    user_id: self.user_id,
-                    map_type: "most_played",
-                },
-            ));
+            let route = Route::GetUserBeatmapsets {
+                user_id: self.user_id,
+                map_type: "most_played",
+            };
+
+            let req = Request::with_query(route, query);
 
             Box::pin(self.osu.inner.request(req))
         }
@@ -461,13 +459,12 @@ impl<'a> GetUserMostPlayed<'a> {
                 .osu
                 .cache_user(self.user_id.take().unwrap())
                 .map_ok(move |user_id| {
-                    Request::from((
-                        query,
-                        Route::GetUserBeatmapsets {
-                            user_id,
-                            map_type: "most_played",
-                        },
-                    ))
+                    let route = Route::GetUserBeatmapsets {
+                        user_id,
+                        map_type: "most_played",
+                    };
+
+                    Request::with_query(route, query)
                 })
                 .and_then(move |req| osu.request(req));
 
@@ -539,17 +536,17 @@ impl<'a> GetRecentEvents<'a> {
         let mut query = Query::new();
 
         if let Some(limit) = self.limit {
-            query.push("limit", limit.to_string());
+            query.push("limit", &limit);
         }
 
         if let Some(offset) = self.offset {
-            query.push("offset", offset.to_string());
+            query.push("offset", &offset);
         }
 
         #[cfg(not(feature = "cache"))]
         {
             let user_id = self.user_id;
-            let req = Request::from((query, Route::GetRecentEvents { user_id }));
+            let req = Request::with_query(Route::GetRecentEvents { user_id }, query);
 
             Box::pin(self.osu.inner.request(req))
         }
@@ -561,7 +558,9 @@ impl<'a> GetRecentEvents<'a> {
             let fut = self
                 .osu
                 .cache_user(self.user_id.take().unwrap())
-                .map_ok(move |user_id| Request::from((query, Route::GetRecentEvents { user_id })))
+                .map_ok(move |user_id| {
+                    Request::with_query(Route::GetRecentEvents { user_id }, query)
+                })
                 .and_then(move |req| osu.request(req));
 
             Box::pin(fut)
@@ -708,30 +707,29 @@ impl<'a> GetUserScores<'a> {
         let mut query = Query::new();
 
         if let Some(limit) = self.limit {
-            query.push("limit", limit.to_string());
+            query.push("limit", &limit);
         }
 
         if let Some(offset) = self.offset {
-            query.push("offset", offset.to_string());
+            query.push("offset", &offset);
         }
 
         if let Some(mode) = self.mode {
-            query.push("mode", mode.to_string());
+            query.push("mode", &mode.to_string());
         }
 
         if let Some(include_fails) = self.include_fails {
-            query.push("include_fails", (include_fails as u8).to_string());
+            query.push("include_fails", &(include_fails as u8));
         }
 
         #[cfg(not(feature = "cache"))]
         {
-            let req = Request::from((
-                query,
-                Route::GetUserScores {
-                    user_id: self.user_id,
-                    score_type: self.score_type,
-                },
-            ));
+            let route = Route::GetUserScores {
+                user_id: self.user_id,
+                score_type: self.score_type,
+            };
+
+            let req = Request::with_query(route, query);
 
             Box::pin(self.osu.inner.request(req))
         }
@@ -745,13 +743,12 @@ impl<'a> GetUserScores<'a> {
                 .osu
                 .cache_user(self.user_id.take().unwrap())
                 .map_ok(move |user_id| {
-                    Request::from((
-                        query,
-                        Route::GetUserScores {
-                            user_id,
-                            score_type,
-                        },
-                    ))
+                    let route = Route::GetUserScores {
+                        user_id,
+                        score_type,
+                    };
+
+                    Request::with_query(route, query)
                 })
                 .and_then(move |req| osu.request(req));
 
@@ -768,7 +765,7 @@ poll_req!(GetUserScores => Vec<Score>);
 pub struct GetUsers<'a> {
     fut: Option<Pending<'a, Vec<UserCompact>>>,
     osu: &'a Osu,
-    query: Option<Query>,
+    form: Option<Query>,
 }
 
 impl<'a> GetUsers<'a> {
@@ -776,17 +773,14 @@ impl<'a> GetUsers<'a> {
     pub(crate) fn new(osu: &'a Osu, user_ids: &[u32]) -> Self {
         let mut query = Query::new();
 
-        let iter = user_ids
-            .iter()
-            .take(50)
-            .map(|user_id| ("id[]", user_id.to_string()));
-
-        query.extend(iter);
+        for user_id in user_ids.iter().take(50) {
+            query.push("id[]", user_id);
+        }
 
         Self {
             fut: None,
             osu,
-            query: Some(query),
+            form: Some(query),
         }
     }
 
