@@ -34,13 +34,19 @@ fn get_country_ranking() -> CountryRanking {
     }
 }
 
+fn get_cursor() -> Cursor {
+    let json = r#"{"cursor":{"a":123,"b":"henlo","c":true,"d":[1, 2, 3]}}"#;
+
+    serde_json::from_str(json).unwrap()
+}
+
 fn get_date() -> DateTime<Utc> {
     Utc.timestamp(1_500_000_000, 0)
 }
 
 fn get_forum_posts() -> ForumPosts {
     ForumPosts {
-        cursor: Some(ForumPostsCursor { post_id: 0 }),
+        cursor: Some(get_cursor()),
         posts: vec![ForumPost {
             created_at: get_date(),
             deleted_at: Some(get_date()),
@@ -381,6 +387,20 @@ fn get_mapset_events() -> BeatmapsetEvents {
                 user_id: 123456,
                 mapset: get_mapset_compact(),
             },
+            BeatmapsetEvent::OwnerChange {
+                event_id: 9,
+                comment: BeatmapsetCommentOwnerChange {
+                    map_discussion_id: Some(0),
+                    map_discussion_post_id: Some(1),
+                    map_id: 123,
+                    version: "epic version".to_owned(),
+                    new_user_id: 98,
+                    new_username: "new name".to_owned(),
+                },
+                created_at: get_date(),
+                user_id: 99,
+                mapset: get_mapset_compact(),
+            },
             BeatmapsetEvent::Rank {
                 event_id: 7,
                 created_at: get_date(),
@@ -539,7 +559,6 @@ fn get_user() -> User {
     User {
         avatar_url: String::new(),
         comments_count: 0,
-        cover_url: String::new(),
         country: "belgiania".to_owned(),
         country_code: "be".to_owned(),
         cover: UserCover {
@@ -592,16 +611,16 @@ fn get_user() -> User {
             url: String::new(),
         }]),
         beatmap_playcounts_count: Some(3),
-        favourite_beatmapset_count: Some(3),
+        favourite_mapset_count: Some(3),
         follower_count: Some(2),
-        graveyard_beatmapset_count: Some(8),
+        graveyard_mapset_count: Some(8),
         groups: Some(vec![Group {
             id: 1,
             identifier: String::new(),
             is_probationary: true,
             name: "group".to_owned(),
             short_name: "g".to_owned(),
-            description: "epic group".to_owned(),
+            description: Some("epic group".to_owned()),
             color: Some("#FFFFFF".to_owned()),
             modes: Some(vec![GameMode::STD, GameMode::MNA]),
         }]),
@@ -614,7 +633,7 @@ fn get_user() -> User {
         is_nat: Some(true),
         is_restricted: Some(true),
         is_silenced: Some(true),
-        loved_beatmapset_count: Some(3),
+        loved_mapset_count: Some(3),
         mapping_follower_count: Some(5),
         monthly_playcounts: Some(vec![MonthlyCount {
             start_date: Utc.ymd(2017, 01, 01),
@@ -626,7 +645,7 @@ fn get_user() -> User {
         }),
         previous_usernames: Some(vec!["b0b".to_owned()]),
         rank_history: Some(vec![50, 40, 30, 35]),
-        ranked_and_approved_beatmapset_count: Some(800),
+        ranked_mapset_count: Some(800),
         replays_watched_counts: Some(vec![MonthlyCount {
             start_date: Utc.ymd(2017, 01, 01),
             count: 42,
@@ -636,7 +655,7 @@ fn get_user() -> User {
         scores_recent_count: Some(13),
         statistics: Some(get_user_stats()),
         support_level: Some(3),
-        unranked_beatmapset_count: Some(13),
+        pending_mapset_count: Some(13),
         medals: Some(vec![MedalCompact {
             achieved_at: get_date(),
             medal_id: 1,
@@ -678,16 +697,16 @@ fn get_user_compact() -> UserCompact {
             url: String::new(),
             id: None,
         }),
-        favourite_beatmapset_count: Some(34),
+        favourite_mapset_count: Some(34),
         follower_count: Some(2),
-        graveyard_beatmapset_count: Some(34),
+        graveyard_mapset_count: Some(34),
         groups: Some(vec![Group {
             id: 1,
             identifier: String::new(),
             is_probationary: true,
             name: "group".to_owned(),
             short_name: "g".to_owned(),
-            description: "epic group".to_owned(),
+            description: Some("epic group".to_owned()),
             color: Some("#FFFFFF".to_owned()),
             modes: Some(vec![GameMode::STD, GameMode::MNA]),
         }]),
@@ -700,7 +719,7 @@ fn get_user_compact() -> UserCompact {
         is_nat: Some(false),
         is_restricted: Some(false),
         is_silenced: Some(false),
-        loved_beatmapset_count: Some(34),
+        loved_mapset_count: Some(34),
         medals: Some(vec![MedalCompact {
             achieved_at: get_date(),
             medal_id: 1,
@@ -715,7 +734,7 @@ fn get_user_compact() -> UserCompact {
         }),
         previous_usernames: Some(vec!["b0b".to_owned()]),
         rank_history: Some(vec![50, 40, 30, 35]),
-        ranked_and_approved_beatmapset_count: Some(34),
+        ranked_mapset_count: Some(34),
         replays_watched_counts: Some(vec![MonthlyCount {
             start_date: Utc.ymd(2017, 01, 01),
             count: 42,
@@ -725,7 +744,7 @@ fn get_user_compact() -> UserCompact {
         scores_recent_count: Some(34),
         statistics: Some(get_user_stats()),
         support_level: Some(1),
-        unranked_beatmapset_count: Some(34),
+        pending_mapset_count: Some(34),
     }
 }
 
